@@ -2,7 +2,7 @@ from functools import partial
 import os
 
 from karld.loadump import split_file_output_csv
-from karld.loadump import split_multi_line_csv_file
+from karld.loadump import split_csv_file
 from karld.loadump import write_as_csv
 from karld.unicode_io import get_csv_row_writer
 
@@ -23,7 +23,7 @@ def main():
         in_file_path = os.path.join(data_path, filename)
 
         # Split the file, with a default max_lines=2 per shard of the file.
-        split_multi_line_csv_file(in_file_path, out_dir, max_lines=2)
+        split_csv_file(in_file_path, out_dir, max_lines=2)
 
         # Split csv file writing with custom a delimiter
         my_split_file_writer = partial(
@@ -37,7 +37,7 @@ def main():
                                'split_data_ml_pipe',
                                filename.replace('.csv', ''))
 
-        split_multi_line_csv_file(in_file_path, out_dir, max_lines=2,
+        split_csv_file(in_file_path, out_dir, max_lines=2,
                                   split_file_writer=my_split_file_writer)
 
 
